@@ -1,4 +1,4 @@
-use std::convert::TryFrom;
+use std::{fs::OpenOptions, path::PathBuf};
 
 use serde::{Deserialize, Serialize};
 use wiremock::{Mock, MockBuilder, Respond, ResponseTemplate};
@@ -11,15 +11,21 @@ use crate::Config;
 pub mod request;
 pub mod response;
 
-#[derive(Serialize, Deserialize, Debug, Hash, Default)]
+#[derive(Serialize, Deserialize, Debug, Hash)]
 pub struct JsonStub {
+    #[serde(skip_serializing)]
+    pub id: Option<String>,
     #[serde(skip_serializing)]
     pub uuid: Option<String>,
+    #[serde(skip_serializing)]
+    pub priority: Option<u8>,
     pub request: RequestStub,
     pub response: ResponseStub,
 }
 
 impl JsonStub {
+    pub const DEFAULT_PRIORITY: u8 = 5;
+
     pub(crate) fn try_creating_from(self, config: &Config) -> anyhow::Result<Mock> {
         Ok(MockBuilder::try_from(&self.request)?.respond_with(self.into_respond(config)))
     }
@@ -38,4 +44,25 @@ impl JsonStub {
             StubTemplate { template, response: self.response, requires_templating: false }
         }
     }
+}
+
+impl TryFrom<&PathBuf> for JsonStub {
+    type Error = anyhow::Error;
+
+    fn try_from(maybe_stub: &PathBuf) -> anyhow::Result<Self> {
+        let file = OpenOptions::new().read(true).open(&maybe_stub)?;
+        serde_json::from_reader(file).map_err(anyhow::Error::msg)
+    }
+}
+
+impl Default for JsonStub {
+    fn default() -> Self {
+        Self {
+            id: Option::default(),
+            uuid: Option::default(),
+            priority: Some(Self::DEFAULT_PRIORITY),
+            request: RequestStub::default(),
+            response: ResponseStub::default(),
+        }
+    }
 }
\ No newline at end of file
