@@ -1,5 +1,3 @@
-use std::convert::TryFrom;
-
 use wiremock::{Match, Request};
 
 use super::BodyPatternStub;
@@ -19,7 +17,7 @@ impl TryFrom<&BodyPatternStub> for BinaryEqualMatcher {
         body.binary_equal_to.as_ref()
             .filter(|_| body.is_by_binary_equality())
             .and_then(|it| base64::decode(it).ok())
-            .map(BinaryEqualMatcher)
-            .ok_or_else(|| anyhow::Error::msg("No body matcher by binary equality"))
+            .map(Self)
+            .ok_or_else(|| anyhow::Error::msg(""))
     }
 }
\ No newline at end of file
