@@ -10,10 +10,10 @@ use helpers::{
     datetime::NowHelper,
     json_path::JsonPathHelper,
     numbers::NumberHelper,
+    size::SizeHelper,
     string::StringHelper,
     trim::TrimHelper,
     url_encode::UrlEncodingHelper,
-    size::SizeHelper,
 };
 
 use crate::{cloud::opentracing::OpenTracing, model::response::ResponseStub};
@@ -51,7 +51,7 @@ pub struct StubTemplate {
 impl Respond for StubTemplate {
     fn respond(&self, req: &Request) -> ResponseTemplate {
         let mut resp = self.template.clone();
-        resp = OpenTracing(req, self.response.defined_header_keys()).add_opentracing_header(resp);
+        resp = OpenTracing(req).add_opentracing_header(resp, self.response.defined_header_keys());
         if self.requires_templating {
             let data = HandlebarsData::from(req);
             resp = self.response.body.render_response_template(resp, &data);
