@@ -8,8 +8,10 @@ pub mod resp;
 impl From<RecordInput<'_>> for JsonStub {
     fn from((ex, cfg): RecordInput) -> Self {
         Self {
+            id: None,
             uuid: None,
-            request: RequestStub::from((&mut *ex, cfg.clone())),
+            priority: None,
+            request: RequestStub::from((&mut *ex, cfg)),
             response: ResponseStub::from((&mut *ex, cfg)),
         }
     }
