@@ -8,7 +8,6 @@ use reqwest::Client as ReqwestClient;
 use tokio::sync::mpsc::Sender;
 
 use config::RecordConfig;
-use self::http::RecordedExchange;
 use logger::RecordLogger;
 use proxy::Proxy;
 use writer::StubWriter;
@@ -20,6 +19,8 @@ use crate::reqwest_client;
 
 use super::model::JsonStub;
 
+use self::http::RecordedExchange;
+
 mod http;
 mod proxy;
 mod mapping;
@@ -32,7 +33,7 @@ mod logger;
 pub mod core;
 pub mod record_client;
 
-type RecordInput<'a> = (&'a mut RecordedExchange, RecordConfig);
+type RecordInput<'a> = (&'a mut RecordedExchange, &'a RecordConfig);
 
 pub struct StubrRecord {
     addr: SocketAddr,
@@ -52,9 +53,9 @@ impl StubrRecord {
             let method = ex.req().method().to_string();
             let url = ex.req().url().clone();
             let status: u16 = ex.resp().status().into();
-            let stub = JsonStub::from((ex, cfg.clone()));
+            let stub = JsonStub::from((ex, cfg));
             let writer = StubWriter { stub };
-            writer.write(&host, cfg.output)
+            writer.write(&host, cfg.output.as_ref())
                 .map(|f| RecordLogger::success(f, status, &method, &url))
                 .unwrap_or_else(|e| RecordLogger::error(e, status, &method, &url));
         });
