@@ -1,19 +1,18 @@
-use std::{convert::TryFrom, net::TcpListener, path::PathBuf};
+use std::{net::TcpListener, path::{Path, PathBuf}};
 
 use async_std::task::block_on;
 use futures::future::join_all;
+use itertools::Itertools;
 use log::info;
-use wiremock::{Mock, MockServer};
+use wiremock::MockServer;
 
 use any_stub::AnyStubs;
-use stub::StubrMock;
 use stub_finder::StubFinder;
 
-use crate::{cloud::probe::HttpProbe, Config};
+use crate::{cloud::probe::HttpProbe, Config, model::JsonStub};
 #[cfg(feature = "record")]
 use crate::record::{config::RecordConfig, StubrRecord};
 
-mod stub;
 mod any_stub;
 pub mod stub_finder;
 pub mod config;
@@ -129,6 +128,11 @@ impl Stubr {
         self.instance.uri()
     }
 
+    /// Get running server address and concatenate a path to it
+    pub fn path(&self, path: &str) -> String {
+        format!("{}{}", self.uri(), path)
+    }
+
     async fn start_on(port: u16) -> Self {
         if let Ok(listener) = TcpListener::bind(format!("{}:{}", Self::HOST, port)) {
             Self {
@@ -145,11 +149,11 @@ impl Stubr {
 
     fn register_stubs(&self, stub_folder: AnyStubs, config: Config) {
         stub_folder.0.iter()
-            .flat_map(|path| self.find_all_mocks(path, &config).map(move |(m, p)| (m, p, path)))
+            .flat_map(|folder| self.find_all_mocks(folder).map(move |(s, p)| (s, p, folder)))
+            .sorted_by(|(a, _, _), (b, _, _)| a.priority.cmp(&b.priority))
+            .filter_map(|(stub, path, folder)| stub.try_creating_from(&config).ok().map(|mock| (mock, path, folder)))
             .for_each(|(mock, file, folder)| {
-                block_on(async move {
-                    self.instance.register(mock).await;
-                });
+                block_on(async move { self.instance.register(mock).await; });
                 if config.verbose.unwrap_or_default() {
                     let maybe_file_name = file.strip_prefix(&folder).ok().and_then(|file| file.to_str());
                     if let Some(file_name) = maybe_file_name {
@@ -160,13 +164,9 @@ impl Stubr {
     }
 
     #[allow(clippy::needless_lifetimes)]
-    fn find_all_mocks<'a>(&self, from: &PathBuf, config: &'a Config) -> impl Iterator<Item=(Mock, PathBuf)> + 'a {
+    fn find_all_mocks<'a>(&self, from: &Path) -> impl Iterator<Item=(JsonStub, PathBuf)> + 'a {
         StubFinder::find_all_stubs(from)
-            .map(move |path| {
-                StubrMock::try_from((&path, config))
-                    .map(|mock| (mock.0, path))
-            })
-            .filter_map(|it| it.ok())
+            .filter_map(move |path| JsonStub::try_from(&path).ok().map(|stub| (stub, path)))
     }
 
     async fn register_cloud_features(&self) {
@@ -181,45 +181,26 @@ mod server_test {
     #[async_std::test]
     async fn should_find_all_mocks_from_dir() {
         let from = PathBuf::from("tests/stubs/server");
-        let config = Config::default();
-        let mocks = Stubr::start_on_random_port().await
-            .find_all_mocks(&from, &config)
-            .collect::<Vec<(Mock, PathBuf)>>();
-        assert_eq!(mocks.len(), 2);
+        assert!(Stubr::start_on_random_port().await.find_all_mocks(&from).count().gt(&2));
     }
 
     #[async_std::test]
     async fn should_find_all_mocks_from_single_file() {
         let from = PathBuf::from("tests/stubs/server/valid.json");
-        let config = Config::default();
-        let mocks = Stubr::start_on_random_port().await
-            .find_all_mocks(&from, &config)
-            .collect::<Vec<(Mock, PathBuf)>>();
-        assert_eq!(mocks.len(), 1);
+        assert_eq!(Stubr::start_on_random_port().await.find_all_mocks(&from).count(), 1);
     }
 
     #[async_std::test]
     async fn should_not_find_any_mock_when_none_valid() {
         let from = PathBuf::from("tests/stubs/server/invalid");
-        let config = Config::default();
-        let mocks = Stubr::start_on_random_port().await
-            .find_all_mocks(&from, &config)
-            .collect::<Vec<(Mock, PathBuf)>>();
-        assert_eq!(mocks.len(), 0);
+        assert_eq!(Stubr::start_on_random_port().await.find_all_mocks(&from).count(), 0);
     }
 
     #[async_std::test]
     async fn should_not_find_any_mock_when_path_does_not_exist() {
         let from = PathBuf::from("tests/stubs/server/unknown");
-        let config = Config::default();
-        let mocks = Stubr::start_on_random_port().await
-            .find_all_mocks(&from, &config)
-            .collect::<Vec<(Mock, PathBuf)>>();
-        assert_eq!(mocks.len(), 0);
+        assert_eq!(Stubr::start_on_random_port().await.find_all_mocks(&from).count(), 0);
         let from = PathBuf::from("tests/stubs/server/unknown.json");
-        let mocks = Stubr::start_on_random_port().await
-            .find_all_mocks(&from, &config)
-            .collect::<Vec<(Mock, PathBuf)>>();
-        assert_eq!(mocks.len(), 0);
+        assert_eq!(Stubr::start_on_random_port().await.find_all_mocks(&from).count(), 0);
     }
 }
\ No newline at end of file
