@@ -16,7 +16,7 @@ impl StubFinder {
     #[cfg(target_os = "linux")]
     const LIB_PATH_ENV_VAR: &'static str = "LD_LIBRARY_PATH";
 
-    pub fn find_all_stubs(from: &PathBuf) -> impl Iterator<Item=PathBuf> {
+    pub fn find_all_stubs(from: &Path) -> impl Iterator<Item=PathBuf> {
         if from.exists() {
             if from.is_dir() {
                 Self::find_all_stubs_under_dir(from).into_iter()
@@ -24,13 +24,16 @@ impl StubFinder {
         } else { vec![].into_iter() }
     }
 
-    fn find_all_stubs_under_dir(from: &PathBuf) -> Vec<PathBuf> {
+    fn find_all_stubs_under_dir(from: &Path) -> Vec<PathBuf> {
         let mut stubs = vec![];
         if let Ok(mut from) = read_dir(from) {
             while let Some(Ok(entry)) = from.next() {
                 let path = entry.path();
-                if path.is_file() && path.extension().and_then(|ext| ext.to_str()) == Some(Self::JSON_EXTENSION) {
+                if path.is_file() && path.extension().and_then(OsStr::to_str) == Some(Self::JSON_EXTENSION) {
                     stubs.push(path)
+                } else if path.is_dir() {
+                    Self::find_all_stubs_under_dir(&path).into_iter()
+                        .for_each(|s| stubs.push(s))
                 }
             }
         }
@@ -75,7 +78,7 @@ mod stub_finder_test {
     fn should_find_just_json_files_from_dir() {
         let from = PathBuf::from("tests/stubs/server");
         let files = StubFinder::find_all_stubs(&from).collect::<Vec<PathBuf>>();
-        assert_eq!(files.len(), 2);
+        assert!(files.len().gt(&2));
         let file_names = files.iter()
             .map(|it| it.file_name().unwrap().to_str().unwrap())
             .collect_vec();
@@ -97,11 +100,9 @@ mod stub_finder_test {
     #[test]
     fn should_not_find_any_file_when_path_does_not_exist() {
         let from = PathBuf::from("tests/stubs/server/unknown");
-        let files = StubFinder::find_all_stubs(&from).collect::<Vec<PathBuf>>();
-        assert!(files.is_empty());
+        assert_eq!(StubFinder::find_all_stubs(&from).count(), 0);
         let from = PathBuf::from("tests/stubs/server/unknown.json");
-        let files = StubFinder::find_all_stubs(&from).collect::<Vec<PathBuf>>();
-        assert!(files.is_empty());
+        assert_eq!(StubFinder::find_all_stubs(&from).count(), 0);
     }
 
     #[test]
@@ -110,4 +111,17 @@ mod stub_finder_test {
         let files = StubFinder::find_all_stubs_under_dir(&from);
         assert!(files.is_empty());
     }
+
+    #[test]
+    fn should_find_all_stubs_recursively() {
+        let from = PathBuf::from("tests/stubs/recur");
+        let files = StubFinder::find_all_stubs(&from).collect::<Vec<PathBuf>>();
+        assert_eq!(files.len(), 3);
+        let file_names = files.iter()
+            .map(|it| it.file_name().unwrap().to_str().unwrap())
+            .collect_vec();
+        assert!(file_names.contains(&"get.json"));
+        assert!(file_names.contains(&"post.json"));
+        assert!(file_names.contains(&"delete.json"));
+    }
 }
\ No newline at end of file
